@@ -4,6 +4,7 @@ from reversion.admin import VersionAdmin
 from armstrong.core.arm_content.admin import fieldsets
 from armstrong.core.arm_sections.admin import SectionTreeAdminMixin
 from armstrong import hatband
+from armstrong.apps.related_content.admin import RelatedContentInline
 from .models import Article
 
 
@@ -18,5 +19,9 @@ class ArticleAdmin(SectionTreeAdminMixin, VersionAdmin, hatband.ModelAdmin):
         fieldsets.AUTHORS,
     )
 
+    inlines = [
+        RelatedContentInline,
+    ]
+
 
 admin.site.register(Article, ArticleAdmin)
